task TNseq {
	File ref_dir
	File dbsnp_dir
	String sample
	String SENTIEON_INSTALL_DIR
	String SENTIEON_LICENSE
	String tumor_name
	String normal_name
	String docker
	String cluster_config

	String fasta
	File germline_resource
	File tumor_recaled_bam
	File tumor_recaled_bam_index
	File tumor_recal_table
	File normal_recaled_bam
	File normal_recaled_bam_index
	File normal_recal_table
	File TNseq_PoN
	String dbsnp
	String disk_size
	File regions

	command <<<
		set -o pipefail
		set -e
		export SENTIEON_LICENSE=${SENTIEON_LICENSE}
		nt=$(nproc)

		${SENTIEON_INSTALL_DIR}/bin/sentieon driver -t $nt --interval ${regions} -r ${ref_dir}/${fasta} -i ${corealigner_bam} --algo TNhaplotyper2 --tumor_sample ${tumor_name} --normal_sample ${normal_name} --dbsnp ${dbsnp_dir}/${dbsnp} ${sample}.TNseq.TN.vcf


		${SENTIEON_INSTALL_DIR}/bin/sentieon driver -t $nt --interval ${regions} -r ${ref_dir}/${fasta} \
		-i ${tumor_recaled_bam} -q ${tumor_recal_table} \
		-i ${normal_recaled_bam} -q ${normal_recal_table} \
		--algo TNseq --tumor_sample ${tumor_name} \
		--normal_sample ${normal_name} \
		--germline_vcf ${germline_resource} \
		--pon ${TNseq_PoN} \
		${sample}.TNseq.TN.tmp.vcf \
		--algo OrientationBias --tumor_sample ${tumor_name} \
		ORIENTATION_DATA \
		--algo ContaminationModel --tumor_sample ${tumor_name} \
		--normal_sample ${normal_name} \
		--vcf ${germline_resource} \
		--tumor_segments CONTAMINATION_DATA.segments \
		CONTAMINATION_DATA
		
		sentieon driver -r REFERENCE \
		--algo TNfilter --tumor_sample ${tumor_name} \
		--normal_sample ${normal_name} \
		-v ${sample}.TNseq.TN.tmp.vcf \
		--contamination CONTAMINATION_DATA \
		--tumor_segments CONTAMINATION_DATA.segments \
		--orientation_priors ORIENTATION_DATA \
		${sample}.TNseq.TN.vcf
	>>>

	runtime {
		docker: docker
		cluster: cluster_config
		systemDisk: "cloud_ssd 40"
		dataDisk: "cloud_ssd " + disk_size + " /cromwell_root/"
	}

	output {
		File TNseq_vcf= "${sample}.TNseq.TN.vcf"
		File TNseq_vcf_index = "${sample}.TNseq.TN.vcf.idx"
	}

}